==> m_abac-1.0.12.tar.gz: m_abac-1.0.12/mobio/libs/abac/policy/conditions/string/not_ends_with.py <==
"""
    String not ends with conditions
"""

from marshmallow import post_load

from .base import StringCondition, StringConditionSchema


class NotEndsWith(StringCondition):
    """
        Condition for string `self.what` ends with `value`
    """

    def _is_satisfied(self, ) -> bool:
        if self.qualifier == self.Qualifier.ForAnyValue:
            for i in self.values:
                if self.value_is_none(i) and self.value_is_none(self.what):
                    continue
                if not self.is_string(i) and not self.is_string(self.what):
                    continue
                elif not self.is_string(i) or not self.is_string(self.what):
                    return True

                if self.delimiter:
                    if not self.what.endswith(self.delimiter + i) or i != self.what:
                        return True
                else:
                    if not self.what.endswith(i):
                        return True
            return False
        else:
            for i in self.values:
                if self.value_is_none(i) and self.value_is_none(self.what):
                    return False
                if not self.is_string(i) and not self.is_string(self.what):
                    return False
                elif not self.is_string(i) or not self.is_string(self.what):
                    continue

                if self.delimiter:
                    if self.what.endswith(self.delimiter + i) or i == self.what:
                        return False
                else:
                    if self.what.endswith(i):
                        return False
            return True


class NotEndsWithSchema(StringConditionSchema):
    """
        JSON schema for ends with string condition
    """

    @post_load
    def post_load(self, data, **_):  # pylint: disable=missing-docstring,no-self-use
        # self.validate(data)
        return NotEndsWith(**data)

==> m_abac-1.0.14.tar.gz: m_abac-1.0.14/mobio/libs/abac/policy/conditions/string/not_ends_with.py <==
"""
    String not ends with conditions
"""

from marshmallow import post_load

from .base import StringCondition, StringConditionSchema


class NotEndsWith(StringCondition):
    """
        Condition for string `self.what` ends with `value`
    """

    def _is_satisfied(self, ) -> bool:
        if self.qualifier == self.Qualifier.ForAnyValue:
            for i in self.values:
                if self.value_is_none(i) and self.value_is_none(self.what):
                    continue
                if not self.is_string(i) and not self.is_string(self.what):
                    continue
                elif not self.is_string(i) or not self.is_string(self.what):
                    return True

                if self.delimiter:
                    # if self.what.endswith(self.delimiter + i) or i == self.what:
                    #     return False
                    if (not self.what.endswith(self.delimiter + i) and i != self.what) or i != self.what:
                        return True
                else:
                    # if self.what.endswith(i):
                    #     return False
                    if not self.what.endswith(i):
                        return True
            return False
        else:
            for i in self.values:
                if self.value_is_none(i) and self.value_is_none(self.what):
                    return False
                if not self.is_string(i) and not self.is_string(self.what):
                    return False
                elif not self.is_string(i) or not self.is_string(self.what):
                    continue

                if self.delimiter:
                    if self.what.endswith(self.delimiter + i) or i == self.what:
                        return False
                else:
                    if self.what.endswith(i):
                        return False
            return True


class NotEndsWithSchema(StringConditionSchema):
    """
        JSON schema for ends with string condition
    """

    @post_load
    def post_load(self, data, **_):  # pylint: disable=missing-docstring,no-self-use
        # self.validate(data)
        return NotEndsWith(**data)
